# frozen_string_literal: true

# app/hermes/models/concerns/common_field.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    module SopraXmlSender
      extend ActiveSupport::Concern

      included do
      
        field :last_xml_validation_report, type: String
        field :last_send_has_error, type: Boolean
        field :last_error_responses, type: Array, default: []
        
        def add_error (error, path, params)
          errors =last_error_responses.unshift({
                                                 date:DateTime.current, 
                                                 path: path,
                                                 playload: params,
                                                 error: error})
          self.set(last_error_responses: errors[0...4],last_send_has_error:true, updated_at: DateTime.current)
        end
        
        def validate_xml(xml, xsd)
          schema_path = [Hermes::Engine.root, %w[spec libs bo_client tasks], xsd].flatten.join('/').to_s
  
          xsd = Nokogiri::XML::Schema(File.read(schema_path))
          xml_validation = xsd.validate(Nokogiri::XML(xml))
          self.set(last_xml_validation_report:  xml_validation.to_s)
          xml_validation.to_s
        end
      end
    end
  end
end
